### TODO

- [x] Load config for relays, self, receiver, and listen
- [] Support to set metadata
- [x] Publish nostrpy to pypi
- [x] Update README with CI/CD
- [] Update README with package information
- [x] Add unit test for CLI

Feel free to add issue(s), add PR(s) for TODO
